@@ -199,6 +199,8 @@ class ExperienceBase(object):
                     item_copy = deepcopy(item)
                     item_copy[exclusive_namespace] = namespace_product_instance
                     final_experience_parameters.append(item_copy)
+        if len(final_experience_parameters) == 0:
+            final_experience_parameters = experience_parameter_product
 
         nb_params = len(final_experience_parameters)
         self._save(final_experience_parameters)
